Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PostgresConnection ¶
type PostgresConnection struct {
Host string `description:"hostname of postgres server" long:"host"`
Port int `description:"port postgres is running on" long:"port"`
Username string `description:"username to connect with" long:"username"`
Password string `description:"password for user" long:"password"`
Database string `description:"database name" long:"database"`
SocketDir string `description:"location of postgres UNIX socket directory (used if host is empty string)" long:"socket-dir"`
ApplicationName string `description:"identify the application to the database using this name" long:"application-name"`
StatementTimeout encoding.Duration `description:"Terminate any database connections that take longer than this" long:"statement-timeout"`
}
func (PostgresConnection) ToConnectionString ¶
func (conf PostgresConnection) ToConnectionString() string
func (PostgresConnection) ToPgxPoolConfig ¶
func (conf PostgresConnection) ToPgxPoolConfig() (*pgxpool.Config, error)
Click to show internal directories.
Click to hide internal directories.