Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Base ¶
type Base struct {
// contains filtered or unexported fields
}
func (*Base) Closed ¶
func (b *Base) Closed() <-chan struct{}
Closed indicates to the broker that the subscriber is closed for business.
func (*Base) Halt ¶
func (b *Base) Halt()
Halt is called by the broker on shutdown, this closes the open channels.
type EventFilter ¶
type MarketStreamEvent ¶
type MarketStreamEvent interface {
StreamEvent
StreamMarketMessage() *eventspb.BusEvent
}
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
func (*Service) ObserveEvents ¶
func (*Service) ObserveEventsOnStream ¶
type StreamSub ¶
type StreamSub struct {
*Base
// contains filtered or unexported fields
}
func NewStreamSub ¶
type StreamSubscription ¶
type StreamSubscription interface {
Halt()
Push(evts ...events.Event)
UpdateBatchSize(ctx context.Context, size int) []*eventspb.BusEvent
Types() []events.Type
GetData(ctx context.Context) []*eventspb.BusEvent
C() chan<- []events.Event
Closed() <-chan struct{}
Skip() <-chan struct{}
SetID(id int)
ID() int
Ack() bool
}
Click to show internal directories.
Click to hide internal directories.